==> qtjambi-webenginecore-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWebEngineCore/QWebEngineUrlSchemeHandler_shell.h <==
#ifndef QWEBENGINEURLSCHEMEHANDLER_SHELL_H
#define QWEBENGINEURLSCHEMEHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <QtJambi/RegistryAPI>


class QWebEngineUrlSchemeHandler_shell : public QWebEngineUrlSchemeHandler, public QtJambiShellInterface
{
public:
    QWebEngineUrlSchemeHandler_shell(QObject* parent0 = nullptr);
    ~QWebEngineUrlSchemeHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void requestStarted(QWebEngineUrlRequestJob* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineUrlSchemeHandler_access : public QWebEngineUrlSchemeHandler
{
    void __qt_requestStarted_QWebEngineUrlRequestJob_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QWEBENGINEURLSCHEMEHANDLER_SHELL_H

==> qtjambi-webenginecore-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiWebEngineCore/QWebEngineUrlSchemeHandler_shell.h <==
#ifndef QWEBENGINEURLSCHEMEHANDLER_SHELL_H
#define QWEBENGINEURLSCHEMEHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <QtJambi/RegistryAPI>


class QWebEngineUrlSchemeHandler_shell : public QWebEngineUrlSchemeHandler, public QtJambiShellInterface
{
public:
    QWebEngineUrlSchemeHandler_shell(QObject* parent0 = nullptr);
    ~QWebEngineUrlSchemeHandler_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QWebEngineUrlSchemeHandler_mshell;
    friend class QWebEngineUrlSchemeHandler_oshell;
};


class QWebEngineUrlSchemeHandler_mshell : public QWebEngineUrlSchemeHandler_shell
{
public:
    using QWebEngineUrlSchemeHandler_shell::QWebEngineUrlSchemeHandler_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWebEngineUrlSchemeHandler_oshell : public QWebEngineUrlSchemeHandler_mshell
{
public:
    using QWebEngineUrlSchemeHandler_mshell::QWebEngineUrlSchemeHandler_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void requestStarted(QWebEngineUrlRequestJob* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineUrlSchemeHandler_access : public QWebEngineUrlSchemeHandler
{
    void __qt_requestStarted_QWebEngineUrlRequestJob_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QWEBENGINEURLSCHEMEHANDLER_SHELL_H
